every_nth(Conflicted): every_nth

Description Usage Arguments

Description

For removing parts of sequences

Usage

1
every_nth(x, nth, empty = TRUE, inverse = TRUE)

Arguments

x

the sequence

nth

keep every nth item, remove everything else

empty

if the removed items should leave an empty space behind

inverse

invert the function, and keep nth items instead of removing them


Eiriksen/Eiriksens-testomatix documentation built on Oct. 30, 2019, 5:31 p.m.