For removing parts of sequences
1 |
x |
the sequence |
nth |
keep every nth item, remove everything else |
empty |
if the removed items should leave an empty space behind |
inverse |
invert the function, and keep nth items instead of removing them |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.